#
# spec file for package maven-install-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with tests
Name:           maven-install-plugin
Version:        3.1.1
Release:        2.6
Summary:        Maven Install Plugin
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugins/maven-install-plugin
Source0:        https://repo1.maven.org/maven2/org/apache/maven/plugins/%{name}/%{version}/%{name}-%{version}-source-release.zip
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.codehaus.plexus:plexus-xml)
BuildRequires:  mvn(org.eclipse.aether:aether-api)
BuildRequires:  mvn(org.eclipse.aether:aether-util)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildArch:      noarch

%description
Copies the project artifacts to the user's local repository.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q

%pom_add_dep org.codehaus.plexus:plexus-xml:3.0.0

%build
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE
%doc NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE
%doc NOTICE

%changelog
* Tue Apr  2 2024 Fridrich Strba <fstrba@suse.com>
- Add dependency on plexus-xml where relevant
  * this will be needed for smooth upgrade to plexus-utils 4.0.0
* Wed May  3 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upsteam version 3.1.1
  * Changes:
    + [MINSTALL-186] Use proper repositorySystemSession
    + [MINSTALL-188] Upgrade Parent to 39
    + [MINSTALL-189] Add parameter to lax project validation
    + [MINSTALL-179] installAtEnd when module does not use
    maven-install-plugin
    + [MINSTALL-183] Don't use metadata from main artifact to fetch
    pom.xml
    + [MINSTALL-185] Install all artifacts in one request
    + [MINSTALL-181] Require Java 8
    + [MINSTALL-184] Cleanup IT tests
    + [MINSTALL-180] Upgrade Parent to 37
    + [MINSTALL-182] Bump mockito-core from 2.28.2 to 4.8.1
    + [MINSTALL-160] Generated POM is not installed if original POM
    exists
    + [MINSTALL-143] Remove a lot of checksum related dead code and
    commented out tests
    + [MINSTALL-164] Create GitHub Actions
    + [MINSTALL-164] Use shared GH Actions
    + [MINSTALL-171] Update plugin (requires Maven 3.2.5+)
    + [MINSTALL-174] Upgrade maven-plugin parent to 36
    + [MINSTALL-115] Install At End feature (no extension)
    + [MINSTALL-177] Streamline the plugin by
- Removed patches:
  * 0001-MINSTALL-143-Remove-a-lot-of-checksum-related-dead-c.patch
  * 0002-MINSTALL-171-Update-plugin-requires-Maven-3.2.5.patch
  * 0003-Fix-tests-with-modular-javas.patch
  * 0004-Fix-tests-with-maven-resolver-1.7.3.patch
    + not needed with this version
- Remove the option --with tests since our mockito is too old
* Wed May 11 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.0.0 milestone M1
  * Bugs:
    + MINSTALL-121: The packaging property should not be used for
    the file extension
    + MINSTALL-130: Remove link to non-existing Codehaus wiki
  * Improvements:
    + MINSTALL-110: install-file should also install bundled
    pom.xml from artifact.
    + MINSTALL-114: Plugin shouldn’t depend on maven-compat
    dependency
    + MINSTALL-118: MavenProject with only attachments must have
    packaging “pom”
    + MINSTALL-124: Remove hard code version for
    maven-invoker-plugin
    + MINSTALL-128: Replace usage of the deprecated ArtifactFactory
    + MINSTALL-134: Remove checksum generation
    + MINSTALL-136: Removed unused dependency
    + MINSTALL-143: Move checksum generation from install to deploy
    plugin
  * Tasks:
    + MINSTALL-129: Use released version of maven-artifact-transfer
    + MINSTALL-131: Rename package to org.apache.maven.plugins
    + MINSTALL-145: Remove unused dependencies in pom
    + MINSTALL-148: Document change about createChecksums
    + MINSTALL-149: Remove updateReleaseInfo parameter
    + MINSTALL-150: Lift JDK minimum to JDK 7
  * Dependency upgrades:
    + MINSTALL-109: Update version of plexus-utils to 3.0.18
    + MINSTALL-111: Upgrade to maven-plugins parent version 27
    + MINSTALL-112: Upgrade maven-plugin-testing-harness to 1.3
    + MINSTALL-113: Upgrade maven-shared-utils to 0.7
    + MINSTALL-117: Upgrade maven-shared-utils to 3.0.0
    + MINSTALL-122: Upgrade maven-shared-components parent to
    version 30
    + MINSTALL-123: Upgrade maven-shared-utils to 3.0.1
    + MINSTALL-125: Upgrade of commons-io to 2.5.
    + MINSTALL-127: Upgrade maven-shared-utils to 3.1.0
    + MINSTALL-137: Upgrade maven-artifact-transfer to version 0.9.1
    + MINSTALL-140: maven-shared-utils 3.1.0 to 3.2.0
    + MINSTALL-141: plexus-utils 3.0.24 to 3.1.0
    + MINSTALL-142: Upgrade parent to 31
    + MINSTALL-144: Upgrade mave-surefire/failsafe-plugin 2.21.0
    + MINSTALL-146: Upgrade maven-plugin parent to version 32
    + MINSTALL-147: Upgrade JUnit to 4.12
- Added patches:
  * 0001-MINSTALL-143-Remove-a-lot-of-checksum-related-dead-c.patch
  * 0002-MINSTALL-171-Update-plugin-requires-Maven-3.2.5.patch
    + Backport upstream fixes to avoid the org.sonatype.aether
    dependencies
  * 0003-Fix-tests-with-modular-javas.patch
    + Add a maven profile to open needed modules to unnamed module
    + Fixes tests with Java 17
  * 0004-Fix-tests-with-maven-resolver-1.7.3.patch
    + maven-resolver 1.7.x had an incompatible change
    + This fix allows us to use the maven-resolver 1.7.3
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Fri Apr  5 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-install-plugin 2.5.2
